@@ -54,9 +54,6 @@ class Server(object):
         self.res = CouchdbResource(uri, transport=transport)
         self.uuids = []
         
-    def __repr__(self):
-        return "<%s %s>" % (self.__class__.__name__, self.dbname)
-        
     def info(self):
         """ info of server 
         :return: dict
@@ -87,7 +84,7 @@ class Server(object):
         if "/" in dbname:
             dbname = url_quote(dbname, safe=":")
         del self[dbname]
-    
+        
     def next_uuid(self, count=None):
         if count is not None:
             self._uuid_batch_count = count
@@ -142,6 +139,9 @@ class Database(object):
         self.server = server
         self.res = server.res.clone()
         self.res.update_uri('/%s' % dbname)
+    
+    def __repr__(self):
+        return "<%s %s>" % (self.__class__.__name__, self.dbname)
         
     @classmethod
     def from_uri(cls, uri, dbname, uuid_batch_count=DEFAULT_UUID_BATCH_COUNT, 
@@ -173,7 +173,7 @@ class Database(object):
         """
 
         try:
-            data = self.res.head(docid)
+            data = self.res.head(self.escape_docid(docid))
         except ResourceNotFound:
             return False
         return True
@@ -201,8 +201,29 @@ class Database(object):
             if not callable(wrapper):
                 raise TypeError("wrapper isn't a callable")
             return wrapper(doc)
-            
+        
         return doc
+
+    def all_docs(self, by_seq=False, **params):
+        """Get all documents from database
+
+        This method has the same behavior than view.
+
+        `all_docs( **params )` is the same as `view('_all_docs', **params)`
+         and `all_docs( by_seq=True, **params)` is the same as
+        `view('_all_docs_by_seq', **params)`
+
+        You can use all(), one(), first() just like views
+
+        Args:
+        :param by_seq: bool, if True the "_all_docs_by_seq" is passed to
+        couchdb. It will return all updated list.
+
+        :return: list, results of the view
+        """
+        if by_seq:
+            return self.view('_all_docs_by_seq', **params)
+        return self.view('_all_docs', **params)
         
     def doc_revisions(self, docid, with_doc=True):
         """ retrieve revisions of a doc
@@ -260,9 +281,8 @@ class Database(object):
             doc['_attachments'] = self.encode_attachments(doc['_attachments'])
             
         if '_id' in doc:
-            doc['_id'] = self.escape_docid(doc['_id'])
-            print doc['_id']
-            res = self.res.put(doc['_id'], payload=doc)
+            docid = self.escape_docid(doc['_id'])
+            res = self.res.put(docid, payload=doc)
         else:
             try:
                 doc['_id'] = self.server.next_uuid()
@@ -302,10 +322,6 @@ class Database(object):
                 if nextid:
                     doc['_id'] = nextid
                     
-            # make sure we have a corret id
-            for doc in ids:
-                doc['_id'] = self.escape_docid(doc['_id'])
-                    
         payload = { "docs": docs }
         if all_or_nothing:
             payload["all-or-nothing"] = True
@@ -338,8 +354,8 @@ class Database(object):
             if not '_id' or not '_rev' in doc:
                 raise KeyError('_id and _rev are required to delete a doc')
                 
-            doc['_id'] = self.escape_docid(doc['_id'])
-            result = self.res.delete(doc['_id'], rev=doc['_rev'])
+            docid = self.escape_docid(doc['_id'])
+            result = self.res.delete(docid, rev=doc['_rev'])
         elif isinstance(doc, basestring): # we get a docid
             data = self.res.head(doc)
             response = self.res.get_response()
@@ -385,6 +401,8 @@ class Database(object):
             view_name = view_name[1:]
         if view_name == '_all_docs':
             view_path = view_name
+        elif view_name == '_all_docs_by_seq':
+            view_path = view_name
         else:
             view_name = view_name.split('/')
             dname = view_name.pop(0)
@@ -464,7 +482,10 @@ class Database(object):
         else:
             doc_ = doc
 
-        res = self.res(doc_['_id']).put(name, payload=content, 
+        docid = self.escape_docid(doc_['_id'])
+        name = url_quote(name, safe="")
+            
+        res = self.res(docid).put(name, payload=content, 
                 headers=headers, rev=doc_['_rev'])
 
         if res['ok']:
@@ -479,8 +500,10 @@ class Database(object):
     
         :return: dict, withm member ok setto True if delete was ok.
         """
-
-        return self.res(doc['_id']).delete(name, rev=doc['_rev'])
+        docid = self.escape_docid(doc['_id'])
+        name = url_quote(name, safe="")
+        
+        return self.res(docid).delete(name, rev=doc['_rev'])
 
     def fetch_attachment(self, id_or_doc, name):
         """ get attachment in document
@@ -496,13 +519,14 @@ class Database(object):
         else:
             docid = id_or_doc['_id']
       
+        docid = self.escape_docid(docid)
+        name = url_quote(name, safe="")
         try:
             data = self.res(docid).get(name)
         except ResourceNotFound:
             return None
         return data
         
- 
     def __len__(self):
         return self.info()['doc_count'] 
         
@@ -527,7 +551,12 @@ class Database(object):
         return (len(self) > 0)
         
     def escape_docid(self, docid):
-        docid = url_quote(docid, safe=":/")
+        if docid.startswith('/'):
+            docid = docid[1:]
+        if docid.startswith('_design'):
+            docid = '_design/%s' % url_quote(docid[8:], safe='')
+        else:
+            docid = url_quote(docid, safe='')
         return docid  
 
     def encode_attachments(self, attachments):
@@ -602,13 +631,16 @@ class ViewResults(object):
         return result
 
     def all(self):
+        """ return list of all results """
         return list(self)
 
     def count(self):
+        """ return number of returned results """
         self._fetch_if_needed()
         return len(self._result_cache.get('rows', []))
 
     def fetch(self):
+        """ fetch results and cache them """
         self._result_cache = self.view._exec(**self.params)
         self._total_rows = self._result_cache.get('total_rows')
         self._offset = self._result_cache.get('offset', 0)
@@ -619,12 +651,14 @@ class ViewResults(object):
 
     @property
     def total_rows(self):
+        """ return number of total rows in the view """
         if self._total_rows is None:
             return self.count()
         return self._total_rows
 
     @property
     def offset(self):
+        """ current position in the view """
         self._fetch_if_needed() 
         return self._offset
         
@@ -676,7 +710,8 @@ class View(ViewInterface):
         
     def _exec(self, **params):
         if 'keys' in params:
-            return self._db.res.post(self.view_path, **params)
+            keys = params.pop('keys')
+            return self._db.res.post(self.view_path, payload={ 'keys': keys }, **params)
         else:
             return self._db.res.get(self.view_path, **params)
             
@@ -689,4 +724,4 @@ class TempView(ViewInterface):
 
     def _exec(self, **params):
         return self._db.res.post('_temp_view', payload=self.design,
-                **params)
\ No newline at end of file
+                **params)
