@@ -119,6 +119,9 @@ class CouchdbResource(restclient.Resource):
 
         # always init url safe chars
         self.client.safe=":/"
+        if path is not None  and "%" in path: 
+            # we already encode some parts of url
+            self.client.safe = ":/%"
 
         body = None
         if payload is not None:
@@ -191,14 +194,14 @@ class CouchdbResource(restclient.Resource):
                 data = json.loads(data)
             except ValueError:
                 pass
-        
+                
         return data
 
     def encode_params(self, params):
         _params = {}
         if params:
             for name, value in params.items():
-                if name in ('key', 'startkey', 'endkey', 'keys') \
+                if name in ('key', 'startkey', 'endkey') \
                         or not isinstance(value, basestring):
                     value = json.dumps(value, allow_nan=False,
                             ensure_ascii=False)
