@@ -131,17 +131,47 @@ class ClientDatabaseTestCase(unittest.TestCase):
         del self.Server['couchdbkit_test']
         
     def testDocWithSlashes(self):
-         db = self.Server.create_db('couchdbkit_test')
-         doc = { '_id': "a/b"}
-         db.save_doc(doc)
-         self.assert_( "a/b" in db) 
-         self.assert_( "a/b" in db)
-         
-         doc = { '_id': '_design/a' }
-         db.save_doc(doc)
-         self.assert_( "_design/a" in db)
-         del self.Server['couchdbkit_test']
-        
+        db = self.Server.create_db('couchdbkit_test')
+        doc = { '_id': "a/b"}
+        db.save_doc(doc)
+        self.assert_( "a/b" in db) 
+ 
+        doc = { '_id': "http://a"}
+        db.save_doc(doc)
+        self.assert_( "http://a" in db)
+        doc = db.get("http://a")
+        self.assert_(doc is not None)
+ 
+        def not_found():
+            doc = db.get('http:%2F%2Fa')
+        self.assertRaises(ResourceNotFound, not_found)
+ 
+        self.assert_(doc.get('_id') == "http://a")
+        doc.get('_id')
+
+        doc = { '_id': "http://b"}
+        db.save_doc(doc)
+        self.assert_( "http://b" in db)
+ 
+        doc = { '_id': '_design/a' }
+        db.save_doc(doc)
+        self.assert_( "_design/a" in db)
+        del self.Server['couchdbkit_test']
+    
+    def testMultipleDocWithSlashes(self):
+        db = self.Server.create_db('couchdbkit_test')
+        doc = { '_id': "a/b"}
+        doc1 = { '_id': "http://a"}
+        doc3 = { '_id': '_design/a' }
+        db.bulk_save([doc, doc1, doc3])
+        self.assert_( "a/b" in db) 
+        self.assert_( "http://a" in db)
+        self.assert_( "_design/a" in db)
+        def not_found():
+            doc = db.get('http:%2F%2Fa')
+        self.assertRaises(ResourceNotFound, not_found)
+        del self.Server['couchdbkit_test']
+    
     def testDbLen(self):
         db = self.Server.create_db('couchdbkit_test')
         doc1 = { 'string': 'test', 'number': 4 }
@@ -300,7 +330,38 @@ class ClientDatabaseTestCase(unittest.TestCase):
         attachment = db.fetch_attachment(doc, 'test')
         self.assert_(attachment == None)
         del self.Server['couchdbkit_test']
-
+        
+    def testAttachmentsWithSlashes(self):
+        db = self.Server.create_db('couchdbkit_test')
+        doc = { '_id': 'test/slashes', 'string': 'test', 'number': 4 }
+        db.save_doc(doc)        
+        text_attachment = u"un texte attaché"
+        old_rev = doc['_rev']
+        db.put_attachment(doc, text_attachment, "test", "text/plain")
+        self.assert_(old_rev != doc['_rev'])
+        fetch_attachment = db.fetch_attachment(doc, "test")
+        self.assert_(text_attachment == fetch_attachment)
+        
+        db.put_attachment(doc, text_attachment, "test/test.txt", "text/plain")
+        self.assert_(old_rev != doc['_rev'])
+        fetch_attachment = db.fetch_attachment(doc, "test/test.txt")
+        self.assert_(text_attachment == fetch_attachment)
+        
+        del self.Server['couchdbkit_test']
+        
+        
+    def testAttachmentUnicode8URI(self):
+        db = self.Server.create_db('couchdbkit_test')
+        doc = { '_id': u"éàù/slashes", 'string': 'test', 'number': 4 }
+        db.save_doc(doc)        
+        text_attachment = u"un texte attaché"
+        old_rev = doc['_rev']
+        db.put_attachment(doc, text_attachment, "test", "text/plain")
+        self.assert_(old_rev != doc['_rev'])
+        fetch_attachment = db.fetch_attachment(doc, "test")
+        self.assert_(text_attachment == fetch_attachment)
+        del self.Server['couchdbkit_test']
+        
     def testSaveMultipleDocs(self):
         db = self.Server.create_db('couchdbkit_test')
         docs = [
@@ -423,6 +484,42 @@ class ClientViewTestCase(unittest.TestCase):
         self.assert_(len(results) == 2)
         del self.Server['couchdbkit_test']
 
+    def testAllDocs(self):
+        db = self.Server.create_db('couchdbkit_test')
+        # save 2 docs 
+        doc1 = { '_id': 'test', 'string': 'test', 'number': 4, 
+                'docType': 'test' }
+        db.save_doc(doc1)
+        doc2 = { '_id': 'test2', 'string': 'test', 'number': 2,
+                    'docType': 'test'}
+        db.save_doc(doc2)
+        
+        self.assert_(db.view('_all_docs').count() == 2 )
+        self.assert_(db.view('_all_docs').all() == db.all_docs().all())
+
+        del self.Server['couchdbkit_test']
+
+    def testAllDocsBySeq(self):
+        db = self.Server.create_db('couchdbkit_test')
+        # save 2 docs 
+        doc1 = { '_id': 'test', 'string': 'test', 'number': 4, 
+                'docType': 'test' }
+        db.save_doc(doc1)
+        doc2 = { '_id': 'test2', 'string': 'test', 'number': 2,
+                    'docType': 'test'}
+        db.save_doc(doc2)
+        
+        self.assert_(db.view('_all_docs_by_seq').count() == 2 )
+        self.assert_(db.view('_all_docs_by_seq').all() == db.all_docs(by_seq=True).all())
+        results = db.all_docs(by_seq=True).all()
+        self.assert_(sorted([i["id"] for i in results]) == ["test", "test2"])
+        self.assert_(sorted([i["key"] for i in results]) == [1,2])
+
+        del self.Server['couchdbkit_test']
+
+
+
+
     def testCount(self):
         db = self.Server.create_db('couchdbkit_test')
         # save 2 docs 
@@ -567,6 +664,9 @@ class ClientViewTestCase(unittest.TestCase):
                 endkey="20081108")
         self.assert_(len(results) == 3)
 
+        results = db.view('test/test1', keys=['test', 'machin'] )
+        self.assert_(len(results) == 3)
+
         del self.Server['couchdbkit_test']
 
         
